@@ -7,12 +7,13 @@
 --
 -- X.509 Certificate types and functions
 --
+{-# LANGUAGE FlexibleContexts #-}
+
 module Data.X509.Cert (Certificate(..)) where
 
 import Data.ASN1.Types
-import Data.Time.Clock (UTCTime)
+import Data.Hourglass (DateTime, TimezoneOffset(TimezoneOffset))
 import Control.Applicative ((<$>), (<*>))
-import Control.Monad.Error
 import Data.X509.Internal
 import Data.X509.PublicKey
 import Data.X509.AlgorithmIdentifier
@@ -40,7 +41,7 @@ data Certificate = Certificate
         , certSerial       :: Integer                -- ^ Serial number
         , certSignatureAlg :: SignatureALG           -- ^ Signature algorithm
         , certIssuerDN     :: DistinguishedName      -- ^ Issuer DN
-        , certValidity     :: (UTCTime, UTCTime)     -- ^ Validity period
+        , certValidity     :: (DateTime, DateTime)   -- ^ Validity period (UTC)
         , certSubjectDN    :: DistinguishedName      -- ^ Subject DN
         , certPubKey       :: PubKey                 -- ^ Public key
         , certExtensions   :: Extensions             -- ^ Extensions
@@ -63,7 +64,7 @@ parseCertHeaderSerial = do
         IntVal v -> return v
         _        -> throwError ("missing serial" ++ show n)
 
-parseCertHeaderValidity :: ParseASN1 (UTCTime, UTCTime)
+parseCertHeaderValidity :: ParseASN1 (DateTime, DateTime)
 parseCertHeaderValidity = getNextContainer Sequence >>= toTimeBound
   where toTimeBound [ ASN1Time _ t1 _, ASN1Time _ t2 _ ] = return (t1,t2)
         toTimeBound _                                    = throwError "bad validity format"
@@ -103,8 +104,8 @@ encodeCertificateHeader cert =
         eAlgId    = toASN1 (certSignatureAlg cert) []
         eIssuer   = toASN1 (certIssuerDN cert) []
         (t1, t2)  = certValidity cert
-        eValidity = asn1Container Sequence [ASN1Time TimeGeneralized t1 Nothing
-                                           ,ASN1Time TimeGeneralized t2 Nothing]
+        eValidity = asn1Container Sequence [ASN1Time TimeGeneralized t1 (Just (TimezoneOffset 0))
+                                           ,ASN1Time TimeGeneralized t2 (Just (TimezoneOffset 0))]
         eSubject  = toASN1 (certSubjectDN cert) []
         epkinfo   = toASN1 (certPubKey cert) []
         eexts     = toASN1 (certExtensions cert) []
