@@ -1,10 +1,8 @@
 {-# LANGUAGE ScopedTypeVariables #-}
 module Main where
 
-import Test.Framework (defaultMain, testGroup)
-import Test.Framework.Providers.QuickCheck2 (testProperty)
-
-import Test.QuickCheck
+import Test.Tasty
+import Test.Tasty.QuickCheck
 
 import qualified Data.ByteString as B
 
@@ -17,8 +15,7 @@ import Data.X509
 import qualified Crypto.Types.PubKey.RSA as RSA
 import qualified Crypto.Types.PubKey.DSA as DSA
 
-import Data.Time.Clock
-import Data.Time.Clock.POSIX
+import Data.Hourglass
 
 instance Arbitrary RSA.PublicKey where
     arbitrary = do
@@ -59,6 +56,8 @@ instance Arbitrary SignatureALG where
         , SignatureALG HashMD2 PubKeyALG_RSA
         , SignatureALG HashSHA256 PubKeyALG_RSA
         , SignatureALG HashSHA384 PubKeyALG_RSA
+        , SignatureALG HashSHA512 PubKeyALG_RSA
+        , SignatureALG HashSHA224 PubKeyALG_RSA
         , SignatureALG HashSHA1 PubKeyALG_DSA
         , SignatureALG HashSHA224 PubKeyALG_ECDSA
         , SignatureALG HashSHA256 PubKeyALG_ECDSA
@@ -78,8 +77,10 @@ instance Arbitrary DistinguishedName where
     arbitrary = DistinguishedName <$> (choose (1,5) >>= \l -> replicateM l arbitraryDE)
       where arbitraryDE = (,) <$> arbitrary <*> arbitrary
 
-instance Arbitrary UTCTime where
-    arbitrary = posixSecondsToUTCTime . fromIntegral <$> (arbitrary :: Gen Int)
+instance Arbitrary DateTime where
+    arbitrary = timeConvert <$> (arbitrary :: Gen Elapsed)
+instance Arbitrary Elapsed where
+    arbitrary = Elapsed . Seconds <$> (choose (1, 100000000))
 
 instance Arbitrary Extensions where
     arbitrary = Extensions <$> oneof
@@ -146,7 +147,7 @@ property_extension_id e = case extDecode (extEncode e) of
                                 Right v | v == e    -> True
                                         | otherwise -> error ("expected " ++ show e ++ " got: " ++ show v)
 
-main = defaultMain
+main = defaultMain $ testGroup "X509"
     [ testGroup "marshall"
         [ testProperty "pubkey" (property_unmarshall_marshall_id :: PubKey -> Bool)
         , testProperty "signature alg" (property_unmarshall_marshall_id :: SignatureALG -> Bool)
